@@ -1,20 +1,16 @@
 package Mojar::Config;
 use Mojo::Base -base;
 
-our $VERSION = 0.021;
+our $VERSION = 0.042;
 # Adapted from Mojolicious::Plugin::Config (3.57)
 
+use Carp 'croak';
 use Mojo::Util qw(decode slurp);
 
-# Private function
-
-sub croak { require Carp; goto &Carp::croak; }
-
-# Public methods
-
 sub load {
   my ($self, $file, %param) = @_;
   $param{log}->debug(sprintf 'Reading config file (%s)', $file) if $param{log};
+  croak "Failed to find file ($file)" unless -f $file or -l $file;
   my $content = decode 'UTF-8', slurp $file;
   return $self->parse(\$content, %param);
 }
